@@ -435,7 +435,7 @@ class TemporaryFile(object):
         """
         self.close()
         self.fobj = open(self.filepath, *args, **kwargs)
-        return self.fobj
+        return self
 
     def close(self):
         """Close the file handler. Will be automatically called when the TemporaryFile instance deleting.
@@ -443,3 +443,84 @@ class TemporaryFile(object):
         if self.fobj:
             self.fobj.close()
             self.fobj = None
+
+    @property
+    def buffer(self):
+        return self.fobj.buffer
+
+    @property
+    def closed(self):
+        return self.fobj.closed
+    
+    def detach(self, *args, **kwargs):
+        return self.fobj.detach(*args, **kwargs)
+
+    @property
+    def encoding(self):
+        return self.fobj.encoding
+    
+    @property
+    def errors(self):
+        return self.fobj.errors
+    
+    def fileno(self, *args, **kwargs):
+        return self.fobj.fileno(*args, **kwargs)
+    
+    def flush(self, *args, **kwargs):
+        return self.fobj.flush(*args, **kwargs)
+    
+    def isatty(self, *args, **kwargs):
+        return self.fobj.isatty(*args, **kwargs)
+    
+    @property
+    def line_buffering(self):
+        return self.fobj.line_buffering
+
+    @property
+    def mode(self):
+        return self.fobj.mode
+
+    @property
+    def name(self):
+        return self.fobj.name
+
+    @property
+    def newlines(self):
+        return self.fobj.newlines
+    
+    def read(self, *args, **kwargs):
+        return self.fobj.read(*args, **kwargs)
+    
+    def readable(self, *args, **kwargs):
+        return self.fobj.readable(*args, **kwargs)
+    
+    def readline(self, *args, **kwargs):
+        return self.fobj.readline(*args, **kwargs)
+    
+    def readlines(self, *args, **kwargs):
+        return self.readlines(*args, **kwargs)
+    
+    def reconfigure(self, *args, **kwargs):
+        return self.fobj.reconfigure(*args, **kwargs)
+    
+    def seek(self, *args, **kwargs):
+        return self.fobj.seek(*args, **kwargs)
+    
+    def seekable(self, *args, **kwargs):
+        return self.fobj.seekable(*args, **kwargs)
+
+    def truncate(self, *args, **kwargs):
+        return self.fobj.truncate(*args, **kwargs)
+    
+    def writable(self, *args, **kwargs):
+        return self.fobj.writable(*args, **kwargs)
+    
+    def write(self, *args, **kwargs):
+        return self.fobj.write(*args, **kwargs)
+    
+    @property
+    def write_through(self):
+        return self.fobj.write_through
+    
+    def writelines(self, *args, **kwargs):
+        return self.fobj.writelines(*args, **kwargs)
